@@ -1,6 +1,6 @@
 """
 
-Copyright (C) 2020 Vanessa Sochat.
+Copyright (C) 2020-2022 Vanessa Sochat.
 
 This Source Code Form is subject to the terms of the
 Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
@@ -12,8 +12,7 @@ import sys
 
 
 def parse_extra(extra):
-    """Given a list of extra arguments, parse for known
-    """
+    """Given a list of extra arguments, parse for known"""
     known_single = [
         "--zenodo-file",
         "--doi",
